@@ -21,12 +21,12 @@ from common import gajim
 import nbxmpp
 from nbxmpp.idlequeue import IdleObject
 from nbxmpp import dispatcher_nb, simplexml
-from nbxmpp.plugin import *
+from nbxmpp.plugin import PlugIn
 from nbxmpp.simplexml import ustr
 from nbxmpp.transports_nb import DATA_RECEIVED, DATA_SENT, DATA_ERROR
 from common.zeroconf import zeroconf
 
-from nbxmpp.protocol import *
+from nbxmpp.protocol import Node, NS_STREAMS
 import socket
 import errno
 import sys
